summaryrefslogtreecommitdiffstats
path: root/tools/designer/uic/form.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/designer/uic/form.cpp')
-rw-r--r--tools/designer/uic/form.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/tools/designer/uic/form.cpp b/tools/designer/uic/form.cpp
index 7945865d..be21ee9e 100644
--- a/tools/designer/uic/form.cpp
+++ b/tools/designer/uic/form.cpp
@@ -13,7 +13,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -141,7 +141,7 @@ void Uic::createFormDecl( const TQDomElement &e )
/*
We are generating a few TQImage members that are not strictly
- necessary in some cases. Ideally, we would use retquiredImage,
+ necessary in some cases. Ideally, we would use requiredImage,
which is computed elsewhere, to keep the generated .h and .cpp
files synchronized.
*/
@@ -666,7 +666,7 @@ void Uic::createFormImpl( const TQDomElement &e )
return;
TQString objName = getObjectName( e );
// generate local and local includes retquired
TQStringList globalIncludes, localIncludes;
TQStringList::Iterator it;
@@ -836,8 +836,8 @@ void Uic::createFormImpl( const TQDomElement &e )
out << "#include <qtoolbar.h>" << endl;
}
- // find out what images are retquired
- TQStringList retquiredImages;
+ // find out what images are required
+ TQStringList requiredImages;
static const char *imgTags[] = { "pixmap", "iconset", 0 };
for ( i = 0; imgTags[i] != 0; i++ ) {
nl = e.parentNode().toElement().elementsByTagName( imgTags[i] );
@@ -846,11 +846,11 @@ void Uic::createFormImpl( const TQDomElement &e )
while ( nn.parentNode() != e.parentNode() )
nn = nn.parentNode();
if ( nn.nodeName() != "customwidgets" )
- retquiredImages += nl.item(j).firstChild().toText().data();
+ requiredImages += nl.item(j).firstChild().toText().data();
}
}
- if ( !retquiredImages.isEmpty() || externPixmaps ) {
+ if ( !requiredImages.isEmpty() || externPixmaps ) {
out << "#include <qimage.h>" << endl;
out << "#include <qpixmap.h>" << endl << endl;
}
@@ -884,7 +884,7 @@ void Uic::createFormImpl( const TQDomElement &e )
nl = n.elementsByTagName( "image" );
for ( i = 0; i < (int) nl.length(); i++ ) {
TQString img = registerObject( nl.item(i).toElement().attribute("name") );
- if ( !retquiredImages.contains( img ) )
+ if ( !requiredImages.contains( img ) )
continue;
TQDomElement tmp = nl.item(i).firstChild().toElement();
if ( tmp.tagName() != "data" )
@@ -1042,7 +1042,7 @@ void Uic::createFormImpl( const TQDomElement &e )
}
}
- // create all children, some forms have special retquirements
+ // create all children, some forms have special requirements
if ( objClass == "TQWizard" ) {
for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
@@ -1231,7 +1231,7 @@ void Uic::createFormImpl( const TQDomElement &e )
out << "}" << endl;
out << endl;
// handle application events if retquired
bool needFontEventHandler = FALSE;
bool needSqlTableEventHandler = FALSE;
bool needSqlDataBrowserEventHandler = FALSE;
@@ -666,7 +666,7 @@ void Uic::createFormImpl( const TQDomElement &e )
return;
TQString objName = getObjectName( e );
- // generate local and local includes retquired
+ // generate local and local includes required
TQStringList globalIncludes, localIncludes;
TQStringList::Iterator it;
@@ -1231,7 +1231,7 @@ void Uic::createFormImpl( const TQDomElement &e )
out << "}" << endl;
out << endl;
- // handle application events if retquired
+ // handle application events if required
bool needFontEventHandler = FALSE;
bool needSqlTableEventHandler = FALSE;